@@ -4,7 +4,6 @@
 
 using namespace gpd;
 using namespace std;
-using namespace STD_TR1;
 using namespace google::protobuf;
 using namespace google::protobuf::io;
 using namespace google::protobuf::compiler;
@@ -31,7 +30,7 @@ void MemorySourceTree::AddFile(const string &filename, const char *data, size_t
 }
 
 ZeroCopyInputStream *MemorySourceTree::Open(const string &filename) {
-    unordered_map<string, string>::iterator item = sources.find(filename);
+    STD_TR1::unordered_map<string, string>::iterator item = sources.find(filename);
     if (item == sources.end())
         return NULL;
 
